@@ -28,15 +28,16 @@
 using namespace CalendarSupport;
 using namespace Akonadi;
 
-namespace CalendarSupport
-{
-
+namespace CalendarSupport {
 class IncidenceAttachmentModelPrivate
 {
     IncidenceAttachmentModelPrivate(IncidenceAttachmentModel *qq,
                                     const QPersistentModelIndex &modelIndex,
                                     const Akonadi::Item &item = Akonadi::Item())
-        : q_ptr(qq), m_modelIndex(modelIndex), m_item(item), m_monitor(nullptr)
+        : q_ptr(qq)
+        , m_modelIndex(modelIndex)
+        , m_item(item)
+        , m_monitor(nullptr)
     {
         if (modelIndex.isValid()) {
             QObject::connect(modelIndex.model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
@@ -71,6 +72,7 @@ class IncidenceAttachmentModelPrivate
         }
 
         m_monitor = new Akonadi::Monitor(q_ptr);
+        m_monitor->setObjectName(QStringLiteral("IncidenceAttachmentModelMonitor"));
         m_monitor->setItemMonitored(m_item);
         m_monitor->itemFetchScope().fetchFullPayload(true);
         QObject::connect(m_monitor, SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)),
@@ -102,31 +104,27 @@ class IncidenceAttachmentModelPrivate
     QModelIndex m_modelIndex;
     Akonadi::Item m_item;
     KCalCore::Incidence::Ptr m_incidence;
-    Akonadi::Monitor *m_monitor;
+    Akonadi::Monitor *m_monitor = nullptr;
 };
-
 }
 
 IncidenceAttachmentModel::IncidenceAttachmentModel(const QPersistentModelIndex &modelIndex,
-        QObject *parent)
-    : QAbstractListModel(parent),
-      d_ptr(new IncidenceAttachmentModelPrivate(this, modelIndex))
+                                                   QObject *parent)
+    : QAbstractListModel(parent)
+    , d_ptr(new IncidenceAttachmentModelPrivate(this, modelIndex))
 {
-
 }
 
 IncidenceAttachmentModel::IncidenceAttachmentModel(const Akonadi::Item &item, QObject *parent)
-    : QAbstractListModel(parent),
-      d_ptr(new IncidenceAttachmentModelPrivate(this, QModelIndex(), item))
+    : QAbstractListModel(parent)
+    , d_ptr(new IncidenceAttachmentModelPrivate(this, QModelIndex(), item))
 {
-
 }
 
 IncidenceAttachmentModel::IncidenceAttachmentModel(QObject *parent)
-    : QAbstractListModel(parent),
-      d_ptr(new IncidenceAttachmentModelPrivate(this, QModelIndex()))
+    : QAbstractListModel(parent)
+    , d_ptr(new IncidenceAttachmentModelPrivate(this, QModelIndex()))
 {
-
 }
 
 IncidenceAttachmentModel::~IncidenceAttachmentModel()
@@ -207,9 +205,8 @@ QVariant IncidenceAttachmentModel::data(const QModelIndex &index, int role) cons
     return QVariant();
 }
 
-QVariant IncidenceAttachmentModel::headerData(int section,
-        Qt::Orientation orientation,
-        int role) const
+QVariant IncidenceAttachmentModel::headerData(int section, Qt::Orientation orientation,
+                                              int role) const
 {
     return QAbstractItemModel::headerData(section, orientation, role);
 }
@@ -223,5 +220,3 @@ QHash<int, QByteArray> CalendarSupport::IncidenceAttachmentModel::roleNames() co
 }
 
 #include "moc_incidenceattachmentmodel.cpp"
-
-
